unit uCartaUno;

interface

uses
  Windows,
  Messages,
  SysUtils,
  Classes,
  Graphics,
  Controls,
  Forms,
  Dialogs,
  uCartaBasico;

type

  TBaralhoUno =
    (buZero, buUm, buDois, buTres, buQuatro, buCinco, buSeis, buSete, buOito,
     buNove, buPular, buInverter, buComprar2, buCuringa, buCuringa4);

  TSuiteUno = (suAmarelo, suAzul, suVerde, suVermelho);

  TCartaUno = class(TCartaBasico)
  private
    { Private declarations }
  protected
    function GetCartaDeAcao: Boolean;
    function GetCompraCartas: Integer;
    function GetCuringa: Boolean;
    function GetInverteSentido: Boolean;
    function GetPulaProximo: Boolean;
    function GetValorPonto: Integer;
    function GetCartaUno: TBaralhoUno;
    function GetSuiteUno: TSuiteUno;
    procedure SetCartaUno(pValor: TBaralhoUno);
    procedure SetSuiteUno(pValor: TSuiteUno);
    procedure Paint; override;
  public
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
  published
    property CartaUno: TBaralhoUno read GetCartaUno write SetCartaUno;
    property SuiteUno: TSuiteUno read GetSuiteUno write SetSuiteUno;
    property CompraCartas: Integer read GetCompraCartas;
    property InverteSentido: Boolean read GetInverteSentido;
    property PulaProximo: Boolean read GetPulaProximo;
    property Curinga: Boolean read GetCuringa;
    property CartaDeAcao: Boolean read GetCartaDeAcao;
    property ValorPonto: Integer read GetValorPonto;
  end;

implementation

var
  bmpCartasUno: TBitmap;
  bmpCartasUnoCuringa: TBitmap;
  bmpCartaUnoVirada: TBitmap;

{ TCartaUno }

constructor TCartaUno.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  FCartaAtual := Integer(buZero);
end;

destructor TCartaUno.Destroy;
begin
  inherited Destroy;
end;

function TCartaUno.GetCartaDeAcao: Boolean;
begin
  result := (CartaUno in [buPular, buInverter, buComprar2, buCuringa, buCuringa4]);
end;

function TCartaUno.GetCartaUno: TBaralhoUno;
begin
  Result := TBaralhoUno(FCartaAtual);
end;

function TCartaUno.GetCompraCartas: Integer;
begin
  case CartaUno of
    buComprar2: result := 2;
    buCuringa4: result := 4;
  else
    result := 0;
  end;
end;

function TCartaUno.GetCuringa: Boolean;
begin
  result := (CartaUno in [buCuringa, buCuringa4]);
end;

function TCartaUno.GetInverteSentido: Boolean;
begin
  result := (CartaUno = buInverter);
end;

function TCartaUno.GetPulaProximo: Boolean;
begin
  result := (CartaUno in [buPular, buComprar2, buCuringa4]);
end;

function TCartaUno.GetSuiteUno: TSuiteUno;
begin
  Result := TSuiteUno(FSuite);
end;

function TCartaUno.GetValorPonto: Integer;
begin
  case CartaUno of
    buPular, buInverter, buComprar2: result := 20;
    buCuringa, buCuringa4: result := 50;
  else
    result := FCartaAtual;
  end;
end;

procedure TCartaUno.Paint;
begin
  inherited Paint;

  if FExibir then
  begin
    case CartaUno of
      buCuringa:
        BitBlt(bmpCarta.Canvas.Handle, 0, 0, LARGURA_CARTA, ALTURA_CARTA,
            bmpCartasUnoCuringa.Canvas.Handle, 0, 0, FModoPintura);
      buCuringa4:
        BitBlt(bmpCarta.Canvas.Handle, 0, 0, LARGURA_CARTA, ALTURA_CARTA,
            bmpCartasUnoCuringa.Canvas.Handle, LARGURA_CARTA, 0, FModoPintura);
      else
        BitBlt(bmpCarta.Canvas.Handle, 0, 0, LARGURA_CARTA, ALTURA_CARTA,
            bmpCartasUno.Canvas.Handle, (LongInt(FCartaAtual) * LARGURA_CARTA),
           (LongInt(FSuite) * ALTURA_CARTA), FModoPintura);
    end;
  end
  else
    BitBlt(bmpCarta.Canvas.Handle, 0, 0, LARGURA_CARTA, ALTURA_CARTA,
            bmpCartaUnoVirada.Canvas.Handle, 0, 0, FModoPintura);

  BitBlt(Canvas.Handle, 0, 0, LARGURA_CARTA, ALTURA_CARTA,
          bmpCarta.Canvas.Handle, 0, 0, SRCCOPY);
end;

procedure TCartaUno.SetCartaUno(pValor: TBaralhoUno);
begin
  CartaAtual := Integer(pValor);
end;

procedure TCartaUno.SetSuiteUno(pValor: TSuiteUno);
begin
  Suite := Integer(pValor);
end;

initialization

  if (not Assigned(bmpCartasUno)) then
  begin
    bmpCartasUno := TBitmap.Create;
    bmpCartasUno.LoadFromResourceName(HInstance, 'UNO_CARTAS');
  end;

  if (not Assigned(bmpCartasUnoCuringa)) then
  begin
    bmpCartasUnoCuringa := TBitmap.Create;
    bmpCartasUnoCuringa.LoadFromResourceName(HInstance, 'UNO_CARTAS_CURINGA');
  end;

  if (not Assigned(bmpCartaUnoVirada)) then
  begin
    bmpCartaUnoVirada := TBitmap.Create;
    bmpCartaUnoVirada.LoadFromResourceName(HInstance, 'UNO_CARTA_VIRADA');
  end;

finalization

  if (Assigned(bmpCartasUno)) then
    FreeAndNil(bmpCartasUno);

  if (Assigned(bmpCartaUnoVirada)) then
    FreeAndNil(bmpCartaUnoVirada);

  if (Assigned(bmpCartasUnoCuringa)) then
    FreeAndNil(bmpCartasUnoCuringa);


end.
