unit uReceita;

interface

uses
  Classes, StrUtils, SysUtils, DateUtils, Math;

type
  TReceitaMain = class
  private
    oListReceitas : TList;
  public
    property ListReceitas : TList read oListReceitas write oListReceitas;

    function IndexOfReceita(aID : Integer) : Integer;
    function IndexOfReceitaByTit(aTitulo : string) : Integer;
    function ShowReceita(aTitulo : string) : string;
    function GetIDReceita(aTitulo : string) : Integer;
    procedure Clear;

    constructor Create;
    destructor Destroy;
  end;

  TReceita = class
  private
    oID : Integer;
    oTitulo: string;
    oDtCadastro : TDateTime;
    oResponsavel : string;
    oRendimeneto : Integer;
    oCategoria : string;
    oPreparo : string;
    oObs : string;
    oLstIngrediente : TList;
  public
    property ID : Integer read oID write oID;
    property Titulo: string read oTitulo write oTitulo;
    property DtCadastro : TDateTime read oDtCadastro write oDtCadastro;
    property Responsavel : string read oResponsavel write oResponsavel;
    property Rendimeneto : Integer read oRendimeneto write oRendimeneto;
    property Categoria : string read oCategoria write oCategoria;
    property Preparo : string read oPreparo write oPreparo;
    property Obs : string read oObs write oObs;
    property LstIngrediente : TList read oLstIngrediente write oLstIngrediente;

    function IndexOfIngrediente(aNome : string) : Integer;

    constructor Create;
    destructor Destroy;
  end;

  TIngrediente = class
  private
    oQuantidade : Double;
    oDescricao : string;
    oUnidade : string;
    oID : Integer;
  public
    property Quantidade : Double read oQuantidade write oQuantidade;
    property Descricao : string read oDescricao write oDescricao;
    property Unidade : string read oUnidade write oUnidade;
    property ID : Integer read oID write oID;
  end;


implementation

uses uDBConfiguration;

{ TReceitaMain }

procedure TReceitaMain.Clear;
var
  I : Integer;
begin
  for I := 0 to oListReceitas.Count - 1 do begin
    TReceita(oListReceitas[I]).Destroy;
  end;
  oListReceitas.Clear;
end;

constructor TReceitaMain.Create;
begin
  oListReceitas := TList.Create;
end;

destructor TReceitaMain.Destroy;
var
  I : Integer;
begin
  for I := 0 to oListReceitas.Count - 1 do begin
    TReceita(oListReceitas[I]).Destroy;
  end;
  oListReceitas.Destroy;
end;

function TReceitaMain.GetIDReceita(aTitulo: string): Integer;
begin
  Result := TReceita(Self.ListReceitas[Self.IndexOfReceitaByTit(aTitulo)]).oID;
end;

function TReceitaMain.IndexOfReceita(aID: Integer): Integer;
var
  I : Integer;
begin
  Result := -1;
  for I := 0 to oListReceitas.Count - 1 do begin
    if (aID = TReceita(oListReceitas[I]).ID) then begin
      Result := I;
      Break;
    end;
  end;
end;

function TReceitaMain.IndexOfReceitaByTit(aTitulo: string): Integer;
var
  I : Integer;
begin
  Result := -1;
  for I := 0 to oListReceitas.Count - 1 do begin
    if (aTitulo = TReceita(oListReceitas[I]).Titulo) then begin
      Result := I;
      Break;
    end;
  end;
end;

function TReceitaMain.ShowReceita(aTitulo: string): string;
var
  vIndex : Integer;
  I : Integer;
begin
  Result := EmptyStr;

  vIndex := Self.IndexOfReceitaByTit(aTitulo);

  if (vIndex = -1) then begin
    Exit;
  end;

  Result := Result + TReceita(Self.ListReceitas[vIndex]).Titulo + #13#10;
  Result := Result + FormatDateTime('dd/mm/yyyy', TReceita(Self.ListReceitas[vIndex]).DtCadastro) + #13#10;
  Result := Result + TReceita(Self.ListReceitas[vIndex]).Responsavel + #13#10;
  Result := Result + IntToStr(TReceita(Self.ListReceitas[vIndex]).Rendimeneto) + #13#10;
  Result := Result + TReceita(Self.ListReceitas[vIndex]).Categoria + #13#10#13#10;

  for I := 0 to TReceita(Self.ListReceitas[vIndex]).LstIngrediente.Count - 1 do begin
    Result := Result + FormatFloat('0.00', TIngrediente(TReceita(Self.ListReceitas[vIndex]).LstIngrediente[I]).Quantidade)+ ' '+
    TIngrediente(TReceita(Self.ListReceitas[vIndex]).LstIngrediente[I]).Unidade + ' - ' +
    TIngrediente(TReceita(Self.ListReceitas[vIndex]).LstIngrediente[I]).Descricao + #13#10;
  end;

  Result := Result + TReceita(Self.ListReceitas[vIndex]).Preparo + #13#10;
  Result := Result + TReceita(Self.ListReceitas[vIndex]).Obs + #13#10;
end;

{ TReceita }

constructor TReceita.Create;
begin
  oLstIngrediente := TList.Create;
end;

destructor TReceita.Destroy;
var
  I : Integer;
begin
  for I := 0 to oLstIngrediente.Count - 1 do begin
    TIngrediente(oLstIngrediente[I]).Destroy;
  end;
  oLstIngrediente.Destroy;
end;

function TReceita.IndexOfIngrediente(aNome: string): Integer;
var
  I : Integer;
begin
  Result := -1;
  for I := 0 to oLstIngrediente.Count - 1 do begin
    if (aNome = TIngrediente(oLstIngrediente[I]).Descricao) then begin
      Result := I;
      Break;
    end;
  end;
end;

end.
